@@ -6,7 +6,7 @@
   (c)  1997--1999 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
 #include "axis-group-item.hh"
-#include "p-col.hh"
+#include "paper-column.hh"
 
 
 
