@@ -21,7 +21,7 @@ Cadenza_req::do_print () const
 bool
 Cadenza_req::do_equal_b (Request const *r) const
 {
-  Cadenza_req*cad =  dynamic_cast <Cadenza_req const *> (r);
+  Cadenza_req const*cad =  dynamic_cast <Cadenza_req const *> (r);
   return cad && cad->on_b_ == on_b_;
 }
 
@@ -35,7 +35,7 @@ Cadenza_req::Cadenza_req (bool b)
 bool
 Bar_req::do_equal_b (Request const *r) const
 {
-  Bar_req * b = dynamic_cast <Bar_req const *> (r);
+  Bar_req  const* b = dynamic_cast <Bar_req const *> (r);
   return b && type_str_ == b->type_str_;
 }
 
@@ -60,7 +60,7 @@ Partial_measure_req::Partial_measure_req (Moment m)
 bool
 Partial_measure_req::do_equal_b (Request const* r) const
 {
-  Partial_measure_req *p = dynamic_cast <Partial_measure_req  const*> (r);
+  Partial_measure_req  const*p = dynamic_cast <Partial_measure_req  const*> (r);
 
   return p&& p->length_mom_ == length_mom_;
 }
@@ -68,7 +68,7 @@ Partial_measure_req::do_equal_b (Request const* r) const
 bool
 Barcheck_req::do_equal_b (Request const *r) const
 {
-  Barcheck_req *b = dynamic_cast<Barcheck_req const*> (r);
+  Barcheck_req  const*b = dynamic_cast<Barcheck_req const*> (r);
   return b;
 }
 
@@ -102,7 +102,7 @@ Time_signature_change_req::do_print () const
 bool
 Time_signature_change_req::do_equal_b (Request const *r) const
 {
-  Time_signature_change_req * m
+  Time_signature_change_req  const* m
     = dynamic_cast <Time_signature_change_req  const*> (r);
 
   return m && m->beats_i_ == beats_i_
@@ -132,7 +132,7 @@ Tempo_req::do_print () const
 bool
 Tempo_req::do_equal_b (Request const *r) const
 {
-  Tempo_req *t = dynamic_cast <Tempo_req const*> (r);
+  Tempo_req const *t = dynamic_cast <Tempo_req const*> (r);
 
   return t&& t->dur_.length_mom ()== dur_.length_mom () && metronome_i_ == t->metronome_i_;
 }
