@@ -30,7 +30,7 @@ Dots::do_post_processing ()
   if (!dots_i_)
     {
       set_elt_property (transparent_scm_sym, SCM_BOOL_T);
-      set_empty (true);
+      set_empty (true, X_AXIS, Y_AXIS);
     }
 }
 
